#include "version.h"
char PROGRAM_TITLE[] = "DsTool";
char VERSION[] = "DsTool for linux, Version Tk";
char BUILD_INFO[] = "Built by bunk@, Wed Aug 22 20:15:55 CEST 2001";
